/*
** Module   : MetaTableRelation.java
** Abstract : Representation of a database relation between two metaschema tables
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --------------------------------Description----------------------------------
** 001 ECF 20131215 Created initial version.
*/

package com.goldencode.p2j.schema;

import java.util.*;
import com.goldencode.ast.*;

/**
 * A representation of a <em>primary-foreign key relation</em> between two Progress metaschema
 * tables. Relations between metaschema tables differ from relations between regular Progress
 * tables, in that traditional foreign keys are used.
 */
class MetaTableRelation
extends TableRelation
{
   /**
    * Constructor.
    * 
    * @param   left
    *          Left table. May not be <code>null</code>.
    * @param   right
    *          Right table. May not be <code>null</code>.
    * @param   key
    *          Set of names of the fields which comprise the join. In this case, the set will
    *          only contain a single value -- the name of the foreign key field.
    */
   public MetaTableRelation(Aast left, Aast right, Set<String> key)
   {
      super(left, right, right, key, MANY_TO_ONE);
   }
   
   /**
    * Get the database schema name for the given table AST.
    * <p>
    * This version override's the parent class to return the standard database qualifier for
    * metaschema tables:  <code>_meta</code>.
    * 
    * @param   table
    *          Target table AST.
    * 
    * @return  Name of the table's database schema.
    */
   @Override
   protected String getDatabase(Aast table)
   {
      return "_meta";
   }
   
   /**
    * Indicates whether this relation uses a real foreign key join (vs. a Progress-style, natural
    * join).
    * 
    * @return  <code>true</code>.
    */
   @Override
   protected boolean hasRealForeignKey()
   {
      return true;
   }
}
